==> org-lsst-ccs-subsystem-focal-plane-buses-1.0.7-sources.jar: org/lsst/ccs/subsystem/focalplane/data/FocalPlaneDataGroup.java <==
package org.lsst.ccs.subsystem.focalplane.data;

import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.lsst.ccs.bus.data.DataProviderInfo;

public enum FocalPlaneDataGroup {
    ASPIC_TEMPERATURE("Aspic Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<aspicId>Aspic[UL])/Temp\\d")),
    REB_TEMPERATURE("Reb Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Temp\\d+")),
    CCD_TEMPERATURE("CCD Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/Temp")),
    CCD_CURRENTS("CCD Currents", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/Seg(?<amplifierId>\\d\\d)/I")),
    CCD_VOLTAGES("CCD Voltages", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/[ORG][DG]V")),
    BIAS_VOLTAGES("Bias Voltages", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Ref\\d+V")),
    RTD_TEMPERATURE("RTD Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/RTDTemp")),
    CLOCK_RAILS("Clock Rails", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/([PS]Clk[UL]|RG[UL]|Ref[PN]12)")),
    BOARD_POWER("Board Power", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(Dig[VI]|Ana[VI]|Clk[HL][VI]|Power|OD[VI])")),
    HEATER("Heater", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Htr[V|W]"));

    private final String name;
    private final Pattern pattern;
    
    static public FocalPlaneDataGroup forName(String name) {
        for (FocalPlaneDataGroup g : values()) {
            if (g.name.equals(name)) {
                return g;
            }
        }
        throw new IllegalArgumentException("No FocalPlaneDataGroup constant with "+ name +" name.");
    }

    private FocalPlaneDataGroup(String name, Pattern pattern) {
        this.name = name;
        this.pattern = pattern;
    }

    public String getName() {
        return name;
    }

    @Override
    public String toString() {
        return getName();
    }
    
    public boolean matchesData(DataProviderInfo dataInfo) {
        return pattern.matcher(dataInfo.getPath()).matches();
    }

    public static FocalPlaneDataGroup findFocalPlaneDataGroup(DataProviderInfo dataInfo) {
        for (FocalPlaneDataGroup dataGroup : FocalPlaneDataGroup.values()) {
            if (dataGroup.matchesData(dataInfo)) {
                return dataGroup;
            }
        }
        return null;
    }

    public void addAttributesToDataInfo(DataProviderInfo dataInfo) {
        Matcher m = pattern.matcher(dataInfo.getPath());
        if ( m.matches() ) {
            dataInfo.addAttribute(DataProviderInfo.Attribute.DATA_GROUP, getName());
            try {
                String raftId = m.group("raftId");
                if (raftId != null) {
                    dataInfo.addAttribute(DataProviderInfo.Attribute.RAFT_ID, raftId);
                }
            } catch (Exception e) {
            }
        }
        
    }    
}

==> org-lsst-ccs-subsystem-focal-plane-buses-1.0.17-sources.jar: org/lsst/ccs/subsystem/focalplane/data/FocalPlaneDataGroup.java <==
package org.lsst.ccs.subsystem.focalplane.data;

import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.lsst.ccs.bus.data.DataProviderInfo;

public enum FocalPlaneDataGroup {
    ASPIC_TEMPERATURE("Aspic Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<aspicId>Aspic[UL])/Temp\\d")),
    REB_TEMPERATURE("Reb Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Temp\\d+")),
    CCD_TEMPERATURE("CCD Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/Temp")),
    CCD_CURRENTS("CCD Currents", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/Seg(?<amplifierId>\\d\\d)/I")),
    CCD_VOLTAGES("CCD Voltages", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(?<sensorId>SW|SG\\d|S\\d\\d)/[ORG][DG]V")),
    BIAS_VOLTAGES("Bias Voltages", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Ref\\d+V")),
    RTD_TEMPERATURE("RTD Temperature", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/RTDTemp")),
    CLOCK_RAILS("Clock Rails", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/([PS]Clk[UL]|RG[UL]|Ref[PN]12)")),
    BOARD_POWER("Board Power", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/(Dig[VI]|Ana[VI]|Clk[HL][VI]|Power|OD[VI])")),
    HEATER("Heater", Pattern.compile("(?<raftId>R\\d\\d)/(?<rebId>Reb\\d|Reb[WG])/Htr[V|W]"));

    private final String name;
    private final Pattern pattern;
    
    static public FocalPlaneDataGroup forName(String name) {
        for (FocalPlaneDataGroup g : values()) {
            if (g.name.equals(name)) {
                return g;
            }
        }
        throw new IllegalArgumentException("No FocalPlaneDataGroup constant with "+ name +" name.");
    }

    private FocalPlaneDataGroup(String name, Pattern pattern) {
        this.name = name;
        this.pattern = pattern;
    }

    public String getName() {
        return name;
    }

    @Override
    public String toString() {
        return getName();
    }
    
    public boolean matchesData(DataProviderInfo dataInfo) {
        return pattern.matcher(dataInfo.getPath()).matches();
    }

    public static FocalPlaneDataGroup findFocalPlaneDataGroup(DataProviderInfo dataInfo) {
        for (FocalPlaneDataGroup dataGroup : FocalPlaneDataGroup.values()) {
            if (dataGroup.matchesData(dataInfo)) {
                return dataGroup;
            }
        }
        return null;
    }

    public void addAttributesToDataInfo(DataProviderInfo dataInfo) {
        //Add the DATA_GROUP attribute only for MONITORING and TRENDING data
        DataProviderInfo.Type dataType = DataProviderInfo.Type.valueOf(dataInfo.getAttributeValue(DataProviderInfo.Attribute.DATA_TYPE));
        if (dataType == DataProviderInfo.Type.MONITORING || dataType == DataProviderInfo.Type.TRENDING) {
            Matcher m = pattern.matcher(dataInfo.getPath());
            if (m.matches()) {
                dataInfo.addAttribute(DataProviderInfo.Attribute.DATA_GROUP, getName());
            }
        }        
    }    
}
